==> open-xchange-core_7.10.0.orig.tar.bz2: open-xchange-core-7.10.0/com.openexchange.chronos.provider.composition.impl/src/com/openexchange/chronos/provider/composition/impl/osgi/CompositingCalendarProviderActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos.provider.composition.impl.osgi;

import static org.slf4j.LoggerFactory.getLogger;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.chronos.provider.CalendarProviderRegistry;
import com.openexchange.chronos.provider.FreeBusyProvider;
import com.openexchange.chronos.provider.account.CalendarAccountService;
import com.openexchange.chronos.provider.composition.IDBasedCalendarAccessFactory;
import com.openexchange.chronos.provider.composition.impl.CalendarProviderRegistryImpl;
import com.openexchange.chronos.provider.composition.impl.CalendarProviderTracker;
import com.openexchange.chronos.provider.composition.impl.CompositingIDBasedCalendarAccessFactory;
import com.openexchange.chronos.provider.composition.impl.quota.CalendarQuotaProvider;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.config.lean.LeanConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.ServiceSet;
import com.openexchange.quota.QuotaProvider;

/**
 * {@link CompositingCalendarProviderActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CompositingCalendarProviderActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link CompositingCalendarProviderActivator}.
     */
    public CompositingCalendarProviderActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { CalendarAccountService.class, LeanConfigurationService.class, CapabilityService.class, ConfigViewFactory.class };
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            getLogger(CompositingCalendarProviderActivator.class).info("starting bundle {}", context.getBundle());
            /*
             * track calendar providers & collect in registry
             */
            ServiceSet<FreeBusyProvider> freeBusyProviders = new ServiceSet<FreeBusyProvider>();
            track(FreeBusyProvider.class, freeBusyProviders);
            CalendarProviderTracker providerTracker = new CalendarProviderTracker(context, this);
            rememberTracker(providerTracker);
            openTrackers();
            CalendarProviderRegistryImpl providerRegistry = new CalendarProviderRegistryImpl(providerTracker, freeBusyProviders);
            /*
             * register services
             */
            registerService(CalendarProviderRegistry.class, providerRegistry);
            registerService(IDBasedCalendarAccessFactory.class, new CompositingIDBasedCalendarAccessFactory(providerRegistry, this));
            registerService(QuotaProvider.class, new CalendarQuotaProvider(this, providerRegistry));
        } catch (Exception e) {
            getLogger(CompositingCalendarProviderActivator.class).error("error starting {}", context.getBundle(), e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        getLogger(CompositingCalendarProviderActivator.class).info("stopping bundle {}", context.getBundle());
        super.stopBundle();
    }

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.chronos.provider.composition.impl/src/com/openexchange/chronos/provider/composition/impl/osgi/CompositingCalendarProviderActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos.provider.composition.impl.osgi;

import static org.slf4j.LoggerFactory.getLogger;
import com.openexchange.capabilities.CapabilityChecker;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.chronos.provider.CalendarProviderRegistry;
import com.openexchange.chronos.provider.FreeBusyProvider;
import com.openexchange.chronos.provider.account.CalendarAccountService;
import com.openexchange.chronos.provider.composition.IDBasedCalendarAccessFactory;
import com.openexchange.chronos.provider.composition.impl.CalendarPrintingCapabilityChecker;
import com.openexchange.chronos.provider.composition.impl.CalendarProviderRegistryImpl;
import com.openexchange.chronos.provider.composition.impl.CalendarProviderTracker;
import com.openexchange.chronos.provider.composition.impl.CompositingIDBasedCalendarAccessFactory;
import com.openexchange.chronos.provider.composition.impl.quota.CalendarQuotaProvider;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.config.lean.LeanConfigurationService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.ServiceSet;
import com.openexchange.quota.QuotaProvider;

/**
 * {@link CompositingCalendarProviderActivator}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 */
public class CompositingCalendarProviderActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link CompositingCalendarProviderActivator}.
     */
    public CompositingCalendarProviderActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { CalendarAccountService.class, LeanConfigurationService.class, CapabilityService.class, ConfigViewFactory.class };
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected void startBundle() throws Exception {
        try {
            getLogger(CompositingCalendarProviderActivator.class).info("starting bundle {}", context.getBundle());
            /*
             * track calendar providers & collect in registry
             */
            ServiceSet<FreeBusyProvider> freeBusyProviders = new ServiceSet<FreeBusyProvider>();
            track(FreeBusyProvider.class, freeBusyProviders);
            CalendarProviderTracker providerTracker = new CalendarProviderTracker(context, this);
            rememberTracker(providerTracker);
            openTrackers();
            CalendarProviderRegistryImpl providerRegistry = new CalendarProviderRegistryImpl(providerTracker, freeBusyProviders);
            /*
             * declare calendar-printing capability & register appropriate checker
             */
            getService(CapabilityService.class).declareCapability(CalendarPrintingCapabilityChecker.CAPABILITY_NAME);
            registerService(CapabilityChecker.class, new CalendarPrintingCapabilityChecker(getService(ConfigViewFactory.class)), 
                singletonDictionary(CapabilityChecker.PROPERTY_CAPABILITIES, CalendarPrintingCapabilityChecker.CAPABILITY_NAME));
            /*
             * register further services
             */
            registerService(CalendarProviderRegistry.class, providerRegistry);
            registerService(IDBasedCalendarAccessFactory.class, new CompositingIDBasedCalendarAccessFactory(providerRegistry, this));
            registerService(QuotaProvider.class, new CalendarQuotaProvider(this, providerRegistry));
        } catch (Exception e) {
            getLogger(CompositingCalendarProviderActivator.class).error("error starting {}", context.getBundle(), e);
            throw e;
        }
    }

    @Override
    protected void stopBundle() throws Exception {
        getLogger(CompositingCalendarProviderActivator.class).info("stopping bundle {}", context.getBundle());
        super.stopBundle();
    }

}
